=================
lib_dzne_workbook
=================

Overview
--------

Library for handling workbooks.

Installation
------------

To install lib_dzne_workbook, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install lib_dzne_workbook

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/lib-dzne-workbook/#files>`_
* `Source <https://github.com/johannes-programming/lib_dzne_workbook>`_

Credits
-------
- Author: Johannes
- Email: johannes-programming@posteo.org

Thank you for using lib_dzne_workbook!